@@ -12,7 +12,7 @@
 
     @copyright: 2000-2004 by Juergen Hermann <jh@web.de>,
                 2005-2007 by MoinMoin:ThomasWaldmann,
-                2007 by MoinMoin:ReimarBauer
+                2007-2013 by MoinMoin:ReimarBauer
     @license: GNU GPL, see COPYING for details.
 """
 
@@ -27,6 +27,7 @@ from MoinMoin.logfile import editlog, eventlog
 from MoinMoin.mail.sendmail import encodeSpamSafeEmail
 from MoinMoin.support.python_compatibility import set
 from MoinMoin.util import filesys, timefuncs, web
+from MoinMoin.util.abuse import log_attempt
 from MoinMoin.events import PageDeletedEvent, PageRenamedEvent, PageCopiedEvent, PageRevertedEvent
 from MoinMoin.events import PagePreSaveEvent, Abort, send_event
 import MoinMoin.events.notification as notification
@@ -88,6 +89,8 @@ class PageEditor(Page):
         @keyword do_revision_backup: if 0, suppress making a page backup per revision
         @keyword do_editor_backup: if 0, suppress saving of draft copies
         @keyword uid_override: override user id and name (default None)
+        @keyword mtime: time for edit-log and event-log (using current time in UTC, if not given)
+                        number of seconds since the epoch, see the time module
         """
         Page.__init__(self, request, page_name, **keywords)
         self._ = request.getText
@@ -95,6 +98,7 @@ class PageEditor(Page):
         self.do_revision_backup = keywords.get('do_revision_backup', 1)
         self.do_editor_backup = keywords.get('do_editor_backup', 1)
         self.uid_override = keywords.get('uid_override', None)
+        self.mtime = keywords.get('mtime')
 
         self.lock = PageLock(self)
 
@@ -165,8 +169,10 @@ class PageEditor(Page):
 
         # check edit permissions
         if not request.user.may.write(self.page_name):
+            log_attempt('edit/no permissions', False, request, pagename=self.page_name)
             msg = _('You are not allowed to edit this page.')
         elif not self.isWritable():
+            log_attempt('edit/immutable', False, request, pagename=self.page_name)
             msg = _('Page is immutable!')
         elif self.rev:
             # Trying to edit an old version, this is not possible via
@@ -548,6 +554,7 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
             return False, _("You can't copy to an empty pagename.")
 
         if not self.request.user.may.write(newpagename):
+            log_attempt('copy/no permissions', False, request, pagename=self.page_name)
             return False, _('You are not allowed to copy this page!')
 
         newpage = PageEditor(request, newpagename)
@@ -600,8 +607,9 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
 
         if not (request.user.may.delete(self.page_name)
                 and request.user.may.write(newpagename)):
+            log_attempt('rename/no permissions', False, request, pagename=self.page_name)
             msg = _('You are not allowed to rename this page!')
-            raise self.AccessDenied, msg
+            raise self.AccessDenied(msg)
 
         if not newpagename:
             return False, _("You can't rename to an empty pagename.")
@@ -707,8 +715,9 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
         success = True
         if not (request.user.may.write(self.page_name)
                 and request.user.may.delete(self.page_name)):
+            log_attempt('delete/no permissions', False, request, pagename=self.page_name)
             msg = _('You are not allowed to delete this page!')
-            raise self.AccessDenied, msg
+            raise self.AccessDenied(msg)
 
         try:
             msg = self.saveText(u"deleted\n", 0, comment=comment or u'', deleted=True, notify=False)
@@ -723,7 +732,7 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
             # XXX do not only catch base class SaveError here, but
             # also the derived classes, so we can give better err msgs
             success = False
-            msg = "SaveError has occured in PageEditor.deletePage. We need locking there."
+            msg = "SaveError has occurred in PageEditor.deletePage. We need locking there."
 
         # delete pagelinks
         arena = self
@@ -913,6 +922,11 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
         _ = self._
         was_deprecated = self.pi.get('deprecated', False)
 
+        if self.mtime is None:
+            mtime_usecs = None
+        else:
+            mtime_usecs = wikiutil.timestamp2version(self.mtime)
+
         self.copy_underlay_page()
 
         # remember conflict state
@@ -959,10 +973,10 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
                     if err.errno == 2: # there was no 'current' file
                         time.sleep(0.1)
                     else:
-                        raise self.CouldNotLock, _("Page could not get locked. Unexpected error (errno=%d).") % err.errno
+                        raise self.CouldNotLock(_("Page could not get locked. Unexpected error (errno=%d).") % err.errno)
 
             if not got_lock:
-                raise self.CouldNotLock, _("Page could not get locked. Missing 'current' file?")
+                raise self.CouldNotLock(_("Page could not get locked. Missing 'current' file?"))
 
             # increment rev number of current(-locked) page
             f = file(clfn)
@@ -971,7 +985,7 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
             try:
                 rev = int(revstr)
             except ValueError, err:
-                raise self.SaveError, _("Unable to determine current page revision from the 'current' file. The page %s is damaged and cannot be edited right now.") % self.page_name
+                raise self.SaveError(_("Unable to determine current page revision from the 'current' file. The page %s is damaged and cannot be edited right now.") % self.page_name)
 
             if not was_deprecated:
                 if self.do_revision_backup or rev == 0:
@@ -989,9 +1003,9 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
                     pass # we don't care for errors in the os.remove
                 # throw a nicer exception
                 if err.errno == errno.ENOSPC:
-                    raise self.SaveError, _("Cannot save page %s, no storage space left.") % self.page_name
+                    raise self.SaveError(_("Cannot save page %s, no storage space left.") % self.page_name)
                 else:
-                    raise self.SaveError, _("An I/O error occurred while saving page %s (errno=%d)") % (self.page_name, err.errno)
+                    raise self.SaveError(_("An I/O error occurred while saving page %s (errno=%d)") % (self.page_name, err.errno))
             # atomically put it in place (except on windows)
             else:
                 filesys.rename(cltfn, clfn)
@@ -1003,11 +1017,13 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
                 # Write the file using text/* mime type
                 f.write(self.encodeTextMimeType(text))
                 f.close()
-                mtime_usecs = wikiutil.timestamp2version(os.path.getmtime(pagefile))
+                if mtime_usecs is None:
+                    mtime_usecs = wikiutil.timestamp2version(os.path.getmtime(pagefile))
                 # set in-memory content
                 self.set_raw_body(text)
             else:
-                mtime_usecs = wikiutil.timestamp2version(time.time())
+                if mtime_usecs is None:
+                    mtime_usecs = wikiutil.timestamp2version(time.time())
                 # set in-memory content
                 self.set_raw_body(None)
 
@@ -1064,14 +1080,16 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
 
         msg = ""
         if not request.user.may.save(self, newtext, rev, **kw):
+            log_attempt('save/no permissions', False, request, pagename=self.page_name)
             msg = _('You are not allowed to edit this page!')
-            raise self.AccessDenied, msg
+            raise self.AccessDenied(msg)
         elif not self.isWritable():
+            log_attempt('save/immutable', False, request, pagename=self.page_name)
             msg = _('Page is immutable!')
-            raise self.Immutable, msg
+            raise self.Immutable(msg)
         elif not newtext:
             msg = _('You cannot save empty pages.')
-            raise self.EmptyPage, msg
+            raise self.EmptyPage(msg)
         elif rev != 0 and rev != self.current_rev():
             # check if we already saved that page
             other = False
@@ -1090,16 +1108,16 @@ Try a different name.""", wiki=True) % (wikiutil.escape(newpagename), )
                     return msg
                 else:
                     msg = _("You already edited this page! Please do not use the back button.")
-                    raise self.EditConflict, msg
+                    raise self.EditConflict(msg)
 
                 msg = _("""Someone else saved this page while you were editing!
 Please review the page and save then. Do not save this page as it is!""")
 
-            raise self.EditConflict, msg
+            raise self.EditConflict(msg)
         elif newtext == self.get_raw_body():
             msg = _('You did not change the page content, not saved!')
             self.lock.release()
-            raise self.Unchanged, msg
+            raise self.Unchanged(msg)
         else:
             from MoinMoin.security import parseACL
             # Get current ACL and compare to new ACL from newtext. If
@@ -1110,8 +1128,9 @@ Please review the page and save then. Do not save this page as it is!""")
             if (not request.user.may.admin(self.page_name) and
                 parseACL(request, newtext).acl != acl.acl and
                 action != "SAVE/REVERT"):
+                log_attempt('acl change/no permissions', False, request, pagename=self.page_name)
                 msg = _("You can't change ACLs on this page since you have no admin rights on it!")
-                raise self.NoAdmin, msg
+                raise self.NoAdmin(msg)
 
         presave = PagePreSaveEvent(request, self, newtext)
         results = send_event(presave)
@@ -1249,14 +1268,14 @@ class PageLock:
         else:
             mins_valid = (secs_valid+59) / 60
             if self.locktype == 'lock':
-                # lout out user
+                # lock out user
+                timestamp_until = self.request.user.getFormattedDateTime(self.timestamp+secs_valid)
                 result = 0, _(
                     "This page is currently ''locked'' for editing by %(owner)s until %(timestamp)s,"
                     " i.e. for %(mins_valid)d minute(s).",
-                    wiki=True) % {'owner': owner, 'timestamp': timestamp, 'mins_valid': mins_valid}
+                    wiki=True) % {'owner': owner, 'timestamp': timestamp_until, 'mins_valid': mins_valid}
             else:
                 # warn user about existing lock
-
                 result = 1, _(
 """This page was opened for editing or last previewed at %(timestamp)s by %(owner)s.<<BR>>
 '''You should ''refrain from editing'' this page for at least another %(mins_valid)d minute(s),
